@@ -458,7 +458,7 @@ classify_attachments (EMapiConnection *conn,
 		if (!filename || !*filename)
 			filename = e_mapi_util_find_array_propval (&attach->properties, PidTagAttachFilename);
 		camel_mime_part_set_filename (part, filename);
-		camel_content_type_set_param (((CamelDataWrapper *) part)->mime_type, "name", filename);
+		camel_content_type_set_param (camel_data_wrapper_get_mime_type_field (CAMEL_DATA_WRAPPER (part)), "name", filename);
 
 		if (is_apple) {
 			CamelMultipart *mp;
@@ -778,20 +778,27 @@ e_mapi_mail_utils_object_to_message (EMapiConnection *conn, /* const */ EMapiObj
 		g_object_unref (stream);
 
 		if (camel_mime_part_construct_from_parser_sync (part, parser, NULL, NULL)) {
-			struct _camel_header_raw *h;
+			const CamelNameValueArray *headers;
+			CamelMedium *msg_medium = CAMEL_MEDIUM (msg);
+			guint ii, len;
 
-			for (h = part->headers; h; h = h->next) {
-				const gchar *value = h->value;
+			headers = camel_medium_get_headers (CAMEL_MEDIUM (part));
+			len = camel_name_value_array_get_length (headers);
+
+			for (ii = 0; ii < len; ii++) {
+				const gchar *header_name = NULL, *header_value = NULL;
 
 				/* skip all headers describing content of a message,
 				   because it's overwritten on message decomposition */
-				if (g_ascii_strncasecmp (h->name, "Content", 7) == 0)
+				if (!camel_name_value_array_get (headers, ii, &header_name, &header_value) ||
+				    !header_name ||
+				    g_ascii_strncasecmp (header_name, "Content", 7) == 0)
 					continue;
 
-				while (value && camel_mime_is_lwsp (*value))
-					value++;
+				while (header_value && camel_mime_is_lwsp (*header_value))
+					header_value++;
 
-				camel_medium_add_header (CAMEL_MEDIUM (msg), h->name, value);
+				camel_medium_add_header (msg_medium, header_name, header_value);
 			}
 		}
 
@@ -1553,7 +1560,7 @@ e_mapi_mail_utils_message_to_object (struct _CamelMimeMessage *message,
 	if ((create_flags & E_MAPI_CREATE_FLAG_SUBMIT) == 0) {
 		time_t msg_time = 0;
 		gint msg_time_offset = 0;
-		GArray *headers;
+		CamelNameValueArray *headers;
 
 		if (namep && *namep)
 			set_value (PidTagSentRepresentingName, namep);
@@ -1583,20 +1590,24 @@ e_mapi_mail_utils_message_to_object (struct _CamelMimeMessage *message,
 			set_value (PidTagMessageDeliveryTime, &msg_date);
 		}
 
-		headers = camel_medium_get_headers (CAMEL_MEDIUM (message));
+		headers = camel_medium_dup_headers (CAMEL_MEDIUM (message));
 		if (headers) {
 			GString *hstr = g_string_new ("");
+			guint len;
 
-			for (ii = 0; ii < headers->len; ii++) {
-				CamelMediumHeader *h = &g_array_index (headers, CamelMediumHeader, ii);
+			len = camel_name_value_array_get_length (headers);
 
-				if (!h->name || !*h->name || g_ascii_strncasecmp (h->name, "X-Evolution", 11) == 0)
+			for (ii = 0; ii < len; ii++) {
+				const gchar *header_name = NULL, *header_value = NULL;
+
+				if (!camel_name_value_array_get (headers, ii, &header_name, &header_value) ||
+				    !header_name || !*header_name || g_ascii_strncasecmp (header_name, "X-Evolution", 11) == 0)
 					continue;
 
-				g_string_append_printf (hstr, "%s: %s\n", h->name, h->value ? h->value : "");
+				g_string_append_printf (hstr, "%s: %s\n", header_name, header_value ? header_value : "");
 			}
 
-			camel_medium_free_headers (CAMEL_MEDIUM (message), headers);
+			camel_name_value_array_free (headers);
 
 			if (hstr->len && hstr->str)
 				set_value (PidTagTransportMessageHeaders, hstr->str);
