@@ -23,7 +23,6 @@
 	((obj), E_TYPE_SOURCE_MAPI_FOLDER, ESourceMapiFolderPrivate))
 
 struct _ESourceMapiFolderPrivate {
-	GMutex property_lock;
 	guint64 fid;
 	guint64 parent_fid;
 	gboolean is_public;
@@ -169,8 +168,6 @@ source_mapi_folder_finalize (GObject *object)
 
 	priv = E_SOURCE_MAPI_FOLDER_GET_PRIVATE (object);
 
-	g_mutex_clear (&priv->property_lock);
-
 	g_free (priv->foreign_username);
 
 	/* Chain up to parent's finalize() method. */
@@ -287,7 +284,6 @@ static void
 e_source_mapi_folder_init (ESourceMapiFolder *extension)
 {
 	extension->priv = E_SOURCE_MAPI_FOLDER_GET_PRIVATE (extension);
-	g_mutex_init (&extension->priv->property_lock);
 
 	extension->priv->fid = 0;
 	extension->priv->parent_fid = 0;
@@ -454,11 +450,11 @@ e_source_mapi_folder_dup_foreign_username (ESourceMapiFolder *extension)
 
 	g_return_val_if_fail (E_IS_SOURCE_MAPI_FOLDER (extension), NULL);
 
-	g_mutex_lock (&extension->priv->property_lock);
+	e_source_extension_property_lock (E_SOURCE_EXTENSION (extension));
 
 	duplicate = g_strdup (e_source_mapi_folder_get_foreign_username (extension));
 
-	g_mutex_unlock (&extension->priv->property_lock);
+	e_source_extension_property_unlock (E_SOURCE_EXTENSION (extension));
 
 	return duplicate;
 }
@@ -469,20 +465,20 @@ e_source_mapi_folder_set_foreign_username (ESourceMapiFolder *extension,
 {
 	g_return_if_fail (E_IS_SOURCE_MAPI_FOLDER (extension));
 
-	g_mutex_lock (&extension->priv->property_lock);
+	e_source_extension_property_lock (E_SOURCE_EXTENSION (extension));
 
 	if (foreign_username && !*foreign_username)
 		foreign_username = NULL;
 
 	if (g_strcmp0 (extension->priv->foreign_username, foreign_username) == 0) {
-		g_mutex_unlock (&extension->priv->property_lock);
+		e_source_extension_property_unlock (E_SOURCE_EXTENSION (extension));
 		return;
 	}
 
 	g_free (extension->priv->foreign_username);
 	extension->priv->foreign_username = g_strdup (foreign_username);
 
-	g_mutex_unlock (&extension->priv->property_lock);
+	e_source_extension_property_unlock (E_SOURCE_EXTENSION (extension));
 
 	g_object_notify (G_OBJECT (extension), "foreign-username");
 }
